init

Macro init 

macro_rules! init {
    () => { ... };
}
Initialize the workforce skill SDK runtime.

Call this once at the top of your lib.rs. Exports the alloc function that the workforce runtime needs to pass data into your WASM module.

workforce_skill_sdk::init!();