Read and write secrets in the workforce vault.
All paths are automatically scoped to wasm-skills/{skill_name}/ — you
only need to provide the key name relative to your skill.
Requires the vault capability in your Skill.toml.
Read and write secrets in the workforce vault.
All paths are automatically scoped to wasm-skills/{skill_name}/ — you
only need to provide the key name relative to your skill.
Requires the vault capability in your Skill.toml.