macro_rules! init {
() => { ... };
}Expand description
Initialize the workforce skill SDK runtime.
Call this once at the top of your lib.rs. Exports the alloc function
that the workforce runtime needs to pass data into your WASM module.
ⓘ
workforce_skill_sdk::init!();